@@ -2,8 +2,6 @@ import json
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
-from encode_utils.connection import Connection
-
 
 class AccessionStep:
     """
@@ -20,19 +18,6 @@ class AccessionStep:
             FileParams(i) for i in step_params["wdl_files"]
         ]
 
-    def get_portal_step_run(self, aliases: List[str]) -> Dict[str, Any]:
-        """
-        Get the portal's dict representation of the step run with special profile key to
-        enable posting with encode_utils.
-        """
-        payload = {
-            "aliases": aliases,
-            "status": "in progress",
-            "analysis_step_version": self.step_version,
-            Connection.PROFILE_KEY: "analysis_step_runs",
-        }
-        return payload
-
 
 class AccessionSteps:
     def __init__(self, path_to_accession_step_json: Union[str, Path]):
